MinizincData (solverl v1.1.2)

Functions for converting data between Minizinc and Elixir.

Summary

Functions

Check dzn against the model info. Currently only checking for unassigned pars.

Merge list of dzn files and/or maps into a single text that corresponds to a format of .dzn file.

Serialize output produced by MinizincParser to Elixir data.

Types

data_chunk()

@type data_chunk() :: Path.t() | map()

mzn_data()

@type mzn_data() :: data_chunk() | [data_chunk()]

Functions

check_dzn(model_info)

@spec check_dzn(any()) :: :ok | {:error, any()}

Check dzn against the model info. Currently only checking for unassigned pars.

elixir_to_dzn(array)

to_dzn(data)

@spec to_dzn(mzn_data()) :: binary()

Merge list of dzn files and/or maps into a single text that corresponds to a format of .dzn file.

to_elixir(el)

@spec to_elixir(any()) :: binary()

Serialize output produced by MinizincParser to Elixir data.