MinizincSearch (solverl v1.1.2)
Meta-search, such as LNS, find_k_solutions, BAB (todo)...
Summary
Functions
Branch-and-bound
Make a handler that breaks after k solutions found by a given solution handler.
Run for a given number of iterations. 'step_fun' is a function that controls the execution.
Functions
Branch-and-bound
Make a handler that breaks after k solutions found by a given solution handler.
Run for a given number of iterations. 'step_fun' is a function that controls the execution.