MinizincData (solverl v1.1.2)
Functions for converting data between Minizinc and Elixir.
Summary
Functions
Check dzn against the model info. Currently only checking for unassigned pars.
Merge list of dzn files and/or maps into a single text that corresponds to a format of .dzn file.
Serialize output produced by MinizincParser to Elixir data.
Types
@type mzn_data() :: data_chunk() | [data_chunk()]
Functions
Check dzn against the model info. Currently only checking for unassigned pars.
Merge list of dzn files and/or maps into a single text that corresponds to a format of .dzn file.
Serialize output produced by MinizincParser to Elixir data.